Stan Math Library: stan/math/prim/scal/prob/poisson_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
poisson_rng.hpp File Reference
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_less.hpp>`
`#include <stan/math/prim/scal/err/check_nonnegative.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/fun/multiply_log.hpp>`
`#include <stan/math/prim/scal/fun/gamma_q.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <boost/random/poisson_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <cmath>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
int | stan::math::poisson_rng (const double lambda, RNG &rng)

[ Stan Home Page ] © 2011–2016, Stan Development Team.